@@ -3,9 +3,10 @@ BEGIN {
   $Dist::Zilla::PluginBundle::SCHWIGON::AUTHORITY = 'cpan:SCHWIGON';
 }
 # ABSTRACT: Build your distributions like SCHWIGON does
-$Dist::Zilla::PluginBundle::SCHWIGON::VERSION = '0.016';
+$Dist::Zilla::PluginBundle::SCHWIGON::VERSION = '0.017';
 # (well actually like FLORA - as it is shamelessly stolen)
 
+use 5.008;
 use Moose 1.00;
 use Method::Signatures::Simple;
 use Moose::Util::TypeConstraints;
@@ -323,6 +324,7 @@ method configure {
     $self->add_plugins(qw(
         MetaConfig
         MetaJSON
+        MetaProvides::Class
         PkgVersion
         PodSyntaxTests
     ));
